@@ -108,7 +108,7 @@ const Application = new Lang.Class({
     _onShowContactActivate: function(action, parameter) {
         this._createWindow();
         this._checkNetwork();
-        this._mainWindow.window.present();
+        this._mainWindow.present();
 
         let id = parameter.deep_unpack();
 
@@ -123,7 +123,7 @@ const Application = new Lang.Class({
     },
 
     _onQuitActivate: function() {
-        this._mainWindow.window.destroy();
+        this._mainWindow.destroy();
     },
 
     _addContacts: function() {
@@ -212,8 +212,9 @@ const Application = new Lang.Class({
                                                                              'icons']));
         let overlay = new Gtk.Overlay({ visible: true, can_focus: false });
         notificationManager = new NotificationManager.NotificationManager(overlay);
-        this._mainWindow = new MainWindow.MainWindow(this, overlay);
-        this._mainWindow.window.connect('destroy', this._onWindowDestroy.bind(this));
+        this._mainWindow = new MainWindow.MainWindow({ application: this,
+                                                       overlay: overlay });
+        this._mainWindow.connect('destroy', this._onWindowDestroy.bind(this));
     },
 
     vfunc_dbus_register: function(connection, path) {
@@ -228,7 +229,7 @@ const Application = new Lang.Class({
     vfunc_activate: function() {
         this._createWindow();
         this._checkNetwork();
-        this._mainWindow.window.present();
+        this._mainWindow.present();
     },
 
     _onWindowDestroy: function(window) {
