@@ -34,7 +34,6 @@ const FavoritesPopover = imports.favoritesPopover;
 const Geoclue = imports.geoclue;
 const LayersPopover = imports.layersPopover;
 const LocationServiceNotification = imports.locationServiceNotification;
-const MapSource = imports.mapSource;
 const MapView = imports.mapView;
 const PlaceEntry = imports.placeEntry;
 const PlaceStore = imports.placeStore;
@@ -48,45 +47,43 @@ const _WINDOW_MIN_HEIGHT = 500;
 
 const MainWindow = new Lang.Class({
     Name: 'MainWindow',
+    Extends: Gtk.ApplicationWindow,
+    Template: 'resource:///org/gnome/Maps/ui/main-window.ui',
+    InternalChildren: [ 'headerBar',
+                        'grid',
+                        'mainStack',
+                        'noNetworkView',
+                        'gotoUserLocationButton',
+                        'toggleSidebarButton',
+                        'layersButton',
+                        'favoritesButton' ],
+
+    get mapView() {
+        return this._mapView;
+    },
+
+    _init: function(params) {
+        this._overlay = params.overlay;
+        delete params.overlay;
+
+        this.parent(params);
 
-    _init: function(app, overlay) {
         this._configureId = 0;
-        let ui = Utils.getUIObject('main-window', [ 'app-window',
-                                                    'header-bar',
-                                                    'grid',
-                                                    'main-stack',
-                                                    'no-network-view',
-                                                    'goto-user-location-button',
-                                                    'toggle-sidebar-button',
-                                                    'layers-button',
-                                                    'favorites-button' ]);
-        this.window = ui.appWindow;
-        this.window.application = app;
-        this._overlay = overlay;
 
-        this.mapView = new MapView.MapView();
-        overlay.add(this.mapView);
+        this._mapView = new MapView.MapView();
+        this._overlay.add(this._mapView);
 
-        overlay.add_overlay(new MapSource.AttributionLogo());
-
-        this.mapView.gotoUserLocation(false);
+        this._mapView.gotoUserLocation(false);
 
         this._sidebar = this._createSidebar();
 
-        this._contextMenu = new ContextMenu.ContextMenu(this.mapView);
+        this._contextMenu = new ContextMenu.ContextMenu({ mapView: this._mapView });
 
-        ui.layersButton.popover = new LayersPopover.LayersPopover();
-        ui.favoritesButton.popover = new FavoritesPopover.FavoritesPopover({ mapView: this.mapView });
-        this._overlay.add_overlay(new ZoomControl.ZoomControl(this.mapView));
+        this._layersButton.popover = new LayersPopover.LayersPopover();
+        this._favoritesButton.popover = new FavoritesPopover.FavoritesPopover({ mapView: this._mapView });
+        this._overlay.add_overlay(new ZoomControl.ZoomControl(this._mapView));
 
-        this._mainStack = ui.mainStack;
         this._mainStack.add(this._overlay);
-        this._noNetworkView = ui.noNetworkView;
-        this._headerBar = ui.headerBar;
-        this._gotoUserLocationButton = ui.gotoUserLocationButton;
-        this._toggleSidebarButton = ui.toggleSidebarButton;
-        this._layersButton = ui.layersButton;
-        this._favoritesButton = ui.favoritesButton;
         this._busy = new BusyMarker.BusyMarker();
         this._overlay.add_overlay(this._busy);
 
@@ -97,13 +94,13 @@ const MainWindow = new Lang.Class({
 
         this._busySignalId = 0;
 
-        ui.grid.attach(this._sidebar, 1, 0, 1, 1);
+        this._grid.attach(this._sidebar, 1, 0, 1, 1);
 
-        ui.grid.show_all();
+        this._grid.show_all();
     },
 
     _createPlaceEntry: function() {
-        let placeEntry = new PlaceEntry.PlaceEntry({ mapView:       this.mapView,
+        let placeEntry = new PlaceEntry.PlaceEntry({ mapView:       this._mapView,
                                                      visible:       true,
                                                      margin_start:  6,
                                                      margin_end:    6,
@@ -112,35 +109,35 @@ const MainWindow = new Lang.Class({
                                                    });
         placeEntry.connect('notify::place', (function() {
             if (placeEntry.place) {
-                this.mapView.showSearchResult(placeEntry.place);
+                this._mapView.showSearchResult(placeEntry.place);
             }
         }).bind(this));
 
         let popover = placeEntry.popover;
         popover.connect('selected',
-                        this.mapView.grab_focus.bind(this.mapView));
-        this.mapView.view.connect('button-press-event',
-                                  popover.hide.bind(popover));
+                        this._mapView.grab_focus.bind(this._mapView));
+        this._mapView.view.connect('button-press-event',
+                                   popover.hide.bind(popover));
         return placeEntry;
     },
 
     _createSidebar: function() {
-        let sidebar = new Sidebar.Sidebar(this.mapView);
+        let sidebar = new Sidebar.Sidebar(this._mapView);
         Application.routeService.query.connect('notify',
                                                this._setRevealSidebar.bind(this, true));
         sidebar.bind_property('reveal-child',
-                              this.mapView, 'routeVisible',
+                              this._mapView, 'routeVisible',
                               GObject.BindingFlags.BIDIRECTIONAL);
-        this.window.application.bind_property('connected',
-                                              sidebar, 'visible',
-                                              GObject.BindingFlags.DEFAULT);
+        this.application.bind_property('connected',
+                                       sidebar, 'visible',
+                                       GObject.BindingFlags.DEFAULT);
         return sidebar;
     },
 
     _initActions: function() {
-        Utils.addActions(this.window, {
+        Utils.addActions(this, {
             'close': {
-                onActivate: this.window.close.bind(this.window)
+                onActivate: this.close.bind(this)
             },
             'about': {
                 onActivate: this._onAboutActivate.bind(this)
@@ -164,11 +161,11 @@ const MainWindow = new Lang.Class({
             },
             'zoom-in': {
                 accels: ['<Primary>plus'],
-                onActivate: this.mapView.view.zoom_in.bind(this.mapView.view)
+                onActivate: this._mapView.view.zoom_in.bind(this._mapView.view)
             },
             'zoom-out': {
                 accels: ['<Primary>minus'],
-                onActivate:  this.mapView.view.zoom_out.bind(this.mapView.view)
+                onActivate:  this._mapView.view.zoom_out.bind(this._mapView.view)
             },
             'find': {
                 accels: ['<Primary>F'],
@@ -178,21 +175,21 @@ const MainWindow = new Lang.Class({
     },
 
     _initSignals: function() {
-        this.window.connect('delete-event', this._quit.bind(this));
-        this.window.connect('configure-event',
-                            this._onConfigureEvent.bind(this));
-        this.window.connect('window-state-event',
-                            this._onWindowStateEvent.bind(this));
-        this.mapView.view.connect('button-press-event', (function() {
+        this.connect('delete-event', this._quit.bind(this));
+        this.connect('configure-event',
+                     this._onConfigureEvent.bind(this));
+        this.connect('window-state-event',
+                     this._onWindowStateEvent.bind(this));
+        this._mapView.view.connect('button-press-event', (function() {
             // Can not call something that will generate clutter events
             // from a clutter event-handler. So use an idle.
             Mainloop.idle_add((function() {
-                this.mapView.grab_focus();
+                this._mapView.grab_focus();
             }).bind(this));
         }).bind(this));
 
-        this.window.application.connect('notify::connected', (function() {
-            if(this.window.application.connected)
+        this.application.connect('notify::connected', (function() {
+            if (this.application.connected)
                 this._mainStack.visible_child = this._overlay;
             else
                 this._mainStack.visible_child = this._noNetworkView;
@@ -201,7 +198,7 @@ const MainWindow = new Lang.Class({
 
     _updateLocationSensitivity: function() {
         let sensitive = (Application.geoclue.state !== Geoclue.State.INITIAL &&
-                         this.window.application.connected);
+                         this.application.connected);
 
         this._gotoUserLocationButton.sensitive = sensitive;
     },
@@ -219,8 +216,8 @@ const MainWindow = new Lang.Class({
 
         Application.geoclue.connect('notify::state',
                                     this._updateLocationSensitivity.bind(this));
-        this.window.application.connect('notify::connected', (function() {
-            let app = this.window.application;
+        this.application.connect('notify::connected', (function() {
+            let app = this.application;
 
             this._updateLocationSensitivity();
             this._layersButton.sensitive = app.connected;
@@ -232,17 +229,17 @@ const MainWindow = new Lang.Class({
     },
 
     _saveWindowGeometry: function() {
-        let window = this.window.get_window();
+        let window = this.get_window();
         let state = window.get_state();
 
         if (state & Gdk.WindowState.MAXIMIZED)
             return;
 
         // GLib.Variant.new() can handle arrays just fine
-        let size = this.window.get_size();
+        let size = this.get_size();
         Application.settings.set('window-size', size);
 
-        let position = this.window.get_position();
+        let position = this.get_position();
         Application.settings.set('window-position', position);
     },
 
@@ -250,18 +247,18 @@ const MainWindow = new Lang.Class({
         let size = Application.settings.get('window-size');
         if (size.length === 2) {
             let [width, height] = size;
-            this.window.set_default_size(width, height);
+            this.set_default_size(width, height);
         }
 
         let position = Application.settings.get('window-position');
         if (position.length === 2) {
             let [x, y] = position;
 
-            this.window.move(x, y);
+            this.move(x, y);
         }
 
         if (Application.settings.get('window-maximized'))
-            this.window.maximize();
+            this.maximize();
     },
 
     _onConfigureEvent: function(widget, event) {
@@ -329,7 +326,7 @@ const MainWindow = new Lang.Class({
             break;
 
         default:
-            this.mapView.gotoUserLocation(true);
+            this._mapView.gotoUserLocation(true);
             break;
         }
     },
@@ -342,7 +339,7 @@ const MainWindow = new Lang.Class({
     _onMapTypeActivate: function(action, value) {
         action.set_state(value);
         let [mapType, len] = value.get_string();
-        this.mapView.setMapType(MapView.MapType[mapType]);
+        this._mapView.setMapType(MapView.MapType[mapType]);
     },
 
     _onToggleSidebarChangeState: function(action, variant) {
@@ -353,7 +350,7 @@ const MainWindow = new Lang.Class({
     },
 
     _setRevealSidebar: function(value) {
-        let action = this.window.lookup_action('toggle-sidebar');
+        let action = this.lookup_action('toggle-sidebar');
         action.change_state(GLib.Variant.new_boolean(value));
     },
 
@@ -378,7 +375,7 @@ const MainWindow = new Lang.Class({
             wrap_license: true,
 
             modal: true,
-            transient_for: this.window
+            transient_for: this
         });
         aboutDialog.show();
         aboutDialog.connect('response',
@@ -391,7 +388,7 @@ const MainWindow = new Lang.Class({
 
         this._busy.show();
 
-        let stage = this.mapView.view.get_stage();
+        let stage = this._mapView.view.get_stage();
         this._busySignalId = stage.connect('captured-event', function() {
             return true;
         });
@@ -400,7 +397,7 @@ const MainWindow = new Lang.Class({
     unmarkBusy: function() {
         this._busy.hide();
 
-        let stage = this.mapView.view.get_stage();
+        let stage = this._mapView.view.get_stage();
         stage.disconnect(this._busySignalId);
         this._busySignalId = 0;
     }
